#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tasty-smallcheck
version:              0.8.2
visibility:           public
id:                   tasty-smallcheck-0.8.2-9ppEaxxVG3VGfkVx65nHil
key:                  tasty-smallcheck-0.8.2-9ppEaxxVG3VGfkVx65nHil
license:              MIT
maintainer:           Roman Cheplyaka <roma@ro-che.info>
author:               Roman Cheplyaka <roma@ro-che.info>
homepage:             https://github.com/feuerbach/tasty
synopsis:             SmallCheck support for the Tasty test framework.
description:          SmallCheck support for the Tasty test framework.
category:             Testing
abi:                  cc4f1fcc83dadf6e953935148334051c
exposed:              True
exposed-modules:      Test.Tasty.SmallCheck
import-dirs:          /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tasty-smallcheck-0.8.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tasty-smallcheck
hs-libraries:         HStasty-smallcheck-0.8.2-9ppEaxxVG3VGfkVx65nHil
depends:
    base-4.18.2.1 optparse-applicative-0.18.1.0-1GTn8byg6tu7aER5UFeikt
    smallcheck-1.2.1.1-5nsOdk9v70XAe5XfYMGmby
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig
    tasty-1.5.2-COAfT6a03JnHgIISmSb09C

haddock-interfaces:
    /usr/share/doc/haskell-tasty-smallcheck/html/tasty-smallcheck.haddock

haddock-html:         /usr/share/doc/haskell-tasty-smallcheck/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

